aboutsummaryrefslogtreecommitdiff
path: root/src/modules/commander/commander_tests
diff options
context:
space:
mode:
authorTickTock- <lukecell@safe-mail.net>2014-04-27 14:06:00 -0700
committerTickTock- <lukecell@safe-mail.net>2014-04-27 14:06:00 -0700
commit269800b48c31d78fec900b4beaf3f655a8c18730 (patch)
tree02d5e68319c9b4cce0ca3a169d9c2a32d5d0844e /src/modules/commander/commander_tests
parent6a7b104c2baad7527d35736979ddd1352bf4119d (diff)
downloadpx4-firmware-269800b48c31d78fec900b4beaf3f655a8c18730.tar.gz
px4-firmware-269800b48c31d78fec900b4beaf3f655a8c18730.tar.bz2
px4-firmware-269800b48c31d78fec900b4beaf3f655a8c18730.zip
renamed EASY to POSHOLD and SEATBELT to ALTHOLD
Diffstat (limited to 'src/modules/commander/commander_tests')
-rw-r--r--src/modules/commander/commander_tests/state_machine_helper_test.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/modules/commander/commander_tests/state_machine_helper_test.cpp b/src/modules/commander/commander_tests/state_machine_helper_test.cpp
index 8a946543d..b440e561b 100644
--- a/src/modules/commander/commander_tests/state_machine_helper_test.cpp
+++ b/src/modules/commander/commander_tests/state_machine_helper_test.cpp
@@ -317,34 +317,34 @@ bool StateMachineHelperTest::mainStateTransitionTest(void)
TRANSITION_CHANGED == main_state_transition(&current_state, new_main_state));
ut_assert("new state: manual", MAIN_STATE_MANUAL == current_state.main_state);
// MANUAL to SEATBELT.
current_state.main_state = MAIN_STATE_MANUAL;
current_state.condition_local_altitude_valid = true;
- new_main_state = MAIN_STATE_SEATBELT;
- ut_assert("tranisition: manual to seatbelt",
+ new_main_state = MAIN_STATE_ALTHOLD;
+ ut_assert("tranisition: manual to althold",
TRANSITION_CHANGED == main_state_transition(&current_state, new_main_state));
- ut_assert("new state: seatbelt", MAIN_STATE_SEATBELT == current_state.main_state);
+ ut_assert("new state: althold", MAIN_STATE_ALTHOLD == current_state.main_state);
- // MANUAL to SEATBELT, invalid local altitude.
+ // MANUAL to ALTHOLD, invalid local altitude.
current_state.main_state = MAIN_STATE_MANUAL;
current_state.condition_local_altitude_valid = false;
- new_main_state = MAIN_STATE_SEATBELT;
+ new_main_state = MAIN_STATE_ALTHOLD;
ut_assert("no transition: invalid local altitude",
TRANSITION_DENIED == main_state_transition(&current_state, new_main_state));
ut_assert("current state: manual", MAIN_STATE_MANUAL == current_state.main_state);
// MANUAL to EASY.
current_state.main_state = MAIN_STATE_MANUAL;
current_state.condition_local_position_valid = true;
- new_main_state = MAIN_STATE_EASY;
- ut_assert("transition: manual to easy",
+ new_main_state = MAIN_STATE_POSHOLD;
+ ut_assert("transition: manual to poshold",
TRANSITION_CHANGED == main_state_transition(&current_state, new_main_state));
- ut_assert("current state: easy", MAIN_STATE_EASY == current_state.main_state);
+ ut_assert("current state: poshold", MAIN_STATE_POSHOLD == current_state.main_state);
- // MANUAL to EASY, invalid local position.
+ // MANUAL to POSHOLD, invalid local position.
current_state.main_state = MAIN_STATE_MANUAL;
current_state.condition_local_position_valid = false;
- new_main_state = MAIN_STATE_EASY;
+ new_main_state = MAIN_STATE_POSHOLD;
ut_assert("no transition: invalid position",
TRANSITION_DENIED == main_state_transition(&current_state, new_main_state));
ut_assert("current state: manual", MAIN_STATE_MANUAL == current_state.main_state);
@@ -317,34 +317,34 @@ bool StateMachineHelperTest::mainStateTransitionTest(void)
TRANSITION_CHANGED == main_state_transition(&current_state, new_main_state));
ut_assert("new state: manual", MAIN_STATE_MANUAL == current_state.main_state);
- // MANUAL to SEATBELT.
+ // MANUAL to ALTHOLD.
current_state.main_state = MAIN_STATE_MANUAL;
current_state.condition_local_altitude_valid = true;
@@ -317,34 +317,34 @@ bool StateMachineHelperTest::mainStateTransitionTest(void)
TRANSITION_DENIED == main_state_transition(&current_state, new_main_state));
ut_assert("current state: manual", MAIN_STATE_MANUAL == current_state.main_state);
- // MANUAL to EASY.
+ // MANUAL to POSHOLD.
current_state.main_state = MAIN_STATE_MANUAL;
current_state.condition_local_position_valid = true;